"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Search = void 0;
const tslib_1 = require("tslib");
const classnames_1 = tslib_1.__importDefault(require("classnames"));
const react_1 = tslib_1.__importStar(require("react"));
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const progress_bar_1 = require("@opensumi/ide-core-browser/lib/progress/progress-bar");
const common_1 = require("../common/");
const search_input_widget_1 = require("./search.input.widget");
const search_module_less_1 = tslib_1.__importDefault(require("./search.module.less"));
const search_replace_widget_1 = require("./search.replace.widget");
const search_rules_widget_1 = require("./search.rules.widget");
const search_tree_view_1 = require("./tree/search-tree.view");
exports.Search = (0, react_1.memo)(({ viewState }) => {
    const searchOptionRef = (0, react_1.useRef)(null);
    const wrapperRef = (0, react_1.useRef)(null);
    const searchTreeService = (0, ide_core_browser_1.useInjectable)(common_1.ISearchTreeService);
    const searchBrowserService = (0, ide_core_browser_1.useInjectable)(common_1.IContentSearchClientService);
    const [offsetTop, setOffsetTop] = (0, react_1.useState)(0);
    const [searchContent, setSearchContent] = (0, react_1.useState)({
        results: new Map(),
        total: { resultNum: 0, fileNum: 0 },
        isSearching: false,
        state: common_1.SEARCH_STATE.done,
        searchError: '',
        isShowValidateMessage: false,
    });
    const [replace, setReplace] = (0, react_1.useState)('');
    const [search, setSearch] = (0, react_1.useState)('');
    const { replaceAll, updateUIState, UIState } = searchBrowserService;
    const [showDetail, setShowDetail] = (0, react_1.useState)(UIState.isDetailOpen);
    const searchInputRef = (0, react_1.useRef)();
    const disposable = (0, react_1.useRef)(new ide_core_browser_1.DisposableCollection());
    const updateSearchUIState = (0, react_1.useCallback)(() => {
        setShowDetail(searchBrowserService.UIState.isDetailOpen);
    }, [showDetail, searchBrowserService]);
    const onDetailToggle = (0, react_1.useCallback)(() => {
        updateUIState({ isDetailOpen: !searchBrowserService.UIState.isDetailOpen });
    }, [searchBrowserService]);
    const onSearchFocus = (0, react_1.useCallback)(() => {
        searchTreeService.contextKey.searchInputBoxFocusedKey.set(true);
    }, [searchTreeService]);
    const onSearchBlur = (0, react_1.useCallback)(() => {
        searchTreeService.contextKey.searchInputBoxFocusedKey.set(false);
    }, [searchBrowserService]);
    const onMatchCaseToggle = (0, react_1.useCallback)(() => {
        updateUIState({ isMatchCase: !searchBrowserService.UIState.isMatchCase });
    }, [searchBrowserService]);
    const onRegexToggle = (0, react_1.useCallback)(() => {
        updateUIState({ isUseRegexp: !searchBrowserService.UIState.isUseRegexp });
    }, [searchBrowserService]);
    const onWholeWordToggle = (0, react_1.useCallback)(() => {
        updateUIState({ isWholeWord: !searchBrowserService.UIState.isWholeWord });
    }, [searchBrowserService]);
    const onOnlyOpenEditorsToggle = (0, react_1.useCallback)(() => {
        updateUIState({ isOnlyOpenEditors: !searchBrowserService.UIState.isOnlyOpenEditors });
    }, [searchBrowserService]);
    const onIncludeIgnoredToggle = (0, react_1.useCallback)(() => {
        updateUIState({ isIncludeIgnored: !searchBrowserService.UIState.isIncludeIgnored });
    }, [searchBrowserService]);
    (0, react_1.useEffect)(() => {
        setOffsetTop((searchOptionRef.current && searchOptionRef.current.clientHeight) || 0);
    }, [offsetTop, searchOptionRef.current, searchContent, searchBrowserService, UIState.isDetailOpen]);
    const collapsePanelContainerStyle = {
        width: viewState.width || '100%',
        height: viewState.height,
    };
    const SearchProcess = (0, react_1.useMemo)(() => (react_1.default.createElement("div", { className: search_module_less_1.default['loading-wrap'] },
        react_1.default.createElement(progress_bar_1.Progress, { loading: searchContent.isSearching }))), [searchContent]);
    const onSearch = (0, react_1.useCallback)((e) => {
        if (e && e.key !== ide_core_browser_1.Key.ENTER.code) {
            return;
        }
        setSearchContent(Object.assign(Object.assign({}, searchContent), { results: new Map() }));
        searchBrowserService.search();
    }, [searchBrowserService, searchContent]);
    const onSearchInputChange = (0, react_1.useCallback)((e) => {
        searchBrowserService.onSearchInputChange(e.currentTarget.value || '');
        setSearch(e.currentTarget.value);
    }, [searchBrowserService]);
    const onSearchIncludeChange = (0, react_1.useCallback)((e) => {
        searchBrowserService.onSearchIncludeChange(e.currentTarget.value || '');
    }, [searchBrowserService]);
    const onOpenPreference = (0, react_1.useCallback)(() => {
        searchBrowserService.openPreference();
    }, [searchBrowserService]);
    const onSearchExcludeChange = (0, react_1.useCallback)((e) => {
        searchBrowserService.onSearchExcludeChange(e.currentTarget.value || '');
    }, [searchBrowserService]);
    const onReplaceInputChange = (0, react_1.useCallback)((e) => {
        searchBrowserService.onReplaceInputChange(e.currentTarget.value || '');
        setReplace(e.currentTarget.value);
    }, [replace, searchBrowserService]);
    const updateSearchContent = (0, react_1.useCallback)(() => {
        setSearchContent({
            results: searchBrowserService.searchResults,
            total: searchBrowserService.resultTotal,
            isSearching: searchBrowserService.isSearching,
            state: searchBrowserService.searchState,
            searchError: searchBrowserService.searchError,
            isShowValidateMessage: searchBrowserService.isShowValidateMessage,
            validateMessage: searchBrowserService.validateMessage,
        });
    }, [searchContent, searchBrowserService]);
    const focusSearchInput = (0, react_1.useCallback)((value) => {
        var _a, _b;
        setSearch(value);
        (_a = searchInputRef.current) === null || _a === void 0 ? void 0 : _a.focus();
        (_b = searchInputRef.current) === null || _b === void 0 ? void 0 : _b.select();
    }, [searchInputRef.current, search]);
    (0, react_1.useEffect)(() => {
        disposable.current.push(searchBrowserService.onDidChange(updateSearchContent));
        disposable.current.push(searchBrowserService.onDidTitleChange(updateSearchContent));
        disposable.current.push(searchBrowserService.onDidUIStateChange(updateSearchUIState));
        disposable.current.push(searchBrowserService.onDidSearchStateChange(focusSearchInput));
        return () => {
            disposable.current.dispose();
        };
    }, []);
    (0, react_1.useEffect)(() => {
        if (wrapperRef.current) {
            searchTreeService.initContextKey(wrapperRef.current);
        }
    }, []);
    const renderSearchTreeView = (0, react_1.useCallback)(() => {
        if (searchContent.results.size > 0) {
            return (react_1.default.createElement(search_tree_view_1.SearchTree, { offsetTop: offsetTop, viewState: viewState, state: searchContent.state, total: searchContent.total, search: search, replace: replace, isUseRegexp: searchBrowserService.UIState.isUseRegexp, isMatchCase: searchBrowserService.UIState.isMatchCase }));
        }
        else {
            if (searchContent.state === common_1.SEARCH_STATE.done) {
                return react_1.default.createElement("div", { className: search_module_less_1.default.result_describe }, search && (0, ide_core_browser_1.localize)('search.noResultsFound'));
            }
            return null;
        }
    }, [searchContent, searchBrowserService, offsetTop, search, replace]);
    const renderSearchResults = (0, react_1.useCallback)(() => {
        if (searchContent.searchError || searchContent.state === common_1.SEARCH_STATE.error) {
            return react_1.default.createElement("div", { className: search_module_less_1.default.result_error }, searchContent.searchError);
        }
        else {
            return renderSearchTreeView();
        }
    }, [searchContent, searchBrowserService, offsetTop, search, replace]);
    return (react_1.default.createElement("div", { className: search_module_less_1.default.search_container, style: collapsePanelContainerStyle, ref: wrapperRef },
        SearchProcess,
        react_1.default.createElement("div", { className: search_module_less_1.default.search_options, ref: searchOptionRef },
            react_1.default.createElement(search_input_widget_1.SearchInputWidget, { isDetailOpen: UIState.isDetailOpen, onDetailToggle: onDetailToggle, isMatchCase: UIState.isMatchCase, onMatchCaseToggle: onMatchCaseToggle, isRegex: UIState.isUseRegexp, onRegexToggle: onRegexToggle, isWholeWord: UIState.isWholeWord, onWholeWordToggle: onWholeWordToggle, isShowValidateMessage: searchContent.isShowValidateMessage, validateMessage: searchContent.validateMessage, onSearchFocus: onSearchFocus, onSearchBlur: onSearchBlur, ref: (el) => el && (searchInputRef.current = el), searchValue: searchBrowserService.searchValue, onSearchInputChange: onSearchInputChange, onSearch: onSearch }),
            react_1.default.createElement(search_replace_widget_1.SearchReplaceWidget, { replaceValue: searchBrowserService.replaceValue, onSearch: onSearch, onReplaceRuleChange: onReplaceInputChange, replaceAll: replaceAll, disabled: searchContent.total.fileNum <= 0 }),
            react_1.default.createElement("div", { className: (0, classnames_1.default)(search_module_less_1.default.search_details) }, showDetail && (react_1.default.createElement(search_rules_widget_1.SearchRulesWidget, { includeValue: searchBrowserService.includeValue, excludeValue: searchBrowserService.excludeValue, onSearch: onSearch, onChangeInclude: onSearchIncludeChange, onChangeExclude: onSearchExcludeChange, isOnlyOpenEditors: UIState.isOnlyOpenEditors, isIncludeIgnored: UIState.isIncludeIgnored, onOnlyOpenEditorsToggle: onOnlyOpenEditorsToggle, onIncludeIgnoredToggle: onIncludeIgnoredToggle, onOpenPreference: onOpenPreference })))),
        renderSearchResults()));
});
//# sourceMappingURL=search.view.js.map