"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SearchTree = void 0;
const tslib_1 = require("tslib");
const classnames_1 = tslib_1.__importDefault(require("classnames"));
const react_1 = tslib_1.__importStar(require("react"));
const ide_components_1 = require("@opensumi/ide-components");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const content_search_1 = require("../../common/content-search");
const search_module_less_1 = tslib_1.__importDefault(require("../search.module.less"));
const search_node_1 = require("./search-node");
const tree_model_service_1 = require("./tree-model.service");
const ResultTotalContent = ({ total, state, model }) => {
    const [collapsed, setCollapsed] = (0, react_1.useState)(false);
    const searchModelService = (0, ide_core_browser_1.useInjectable)(tree_model_service_1.SearchModelService);
    const handleFold = (0, react_1.useCallback)(() => {
        const toCollapsed = !collapsed;
        setCollapsed(toCollapsed);
        if (toCollapsed) {
            searchModelService.collapsedAll();
        }
        else {
            searchModelService.expandAll();
        }
    }, [collapsed, searchModelService]);
    const handleRefresh = (0, react_1.useCallback)(() => {
        searchModelService.refresh();
    }, [searchModelService]);
    (0, react_1.useEffect)(() => {
        if (!model) {
            return;
        }
        const dispose = model.root.watcher.on(ide_components_1.TreeNodeEvent.DidChangeExpansionState, () => {
            if (collapsed) {
                setCollapsed(!collapsed);
            }
        });
        return () => {
            dispose.dispose();
        };
    }, [model, collapsed]);
    if (total.resultNum > 0) {
        return (react_1.default.createElement("p", { className: search_module_less_1.default.result_describe },
            react_1.default.createElement("span", { className: search_module_less_1.default.text }, (0, ide_core_browser_1.formatLocalize)('search.files.result', String(total.resultNum), String(total.fileNum))),
            react_1.default.createElement(ide_components_1.Button, { className: (0, classnames_1.default)(search_module_less_1.default.result_fresh, { [search_module_less_1.default.disabled]: state === content_search_1.SEARCH_STATE.doing }), onClick: handleRefresh, type: 'icon', icon: 'refresh', title: (0, ide_core_browser_1.localize)('search.RefreshAction.label') }),
            react_1.default.createElement(ide_components_1.Button, { className: (0, classnames_1.default)(search_module_less_1.default.result_fold, { [search_module_less_1.default.disabled]: state === content_search_1.SEARCH_STATE.doing }), onClick: handleFold, type: 'icon', icon: !collapsed ? 'collapse-all' : 'expand-all', title: (0, ide_core_browser_1.localize)(!collapsed
                    ? 'search.CollapseDeepestExpandedLevelAction.label'
                    : 'search.ExpandDeepestExpandedLevelAction.label') })));
    }
    return null;
};
const SearchTree = ({ offsetTop, total, state, replace, search, viewState, isUseRegexp, isMatchCase, }) => {
    const [model, setModel] = (0, react_1.useState)();
    const searchModelService = (0, ide_core_browser_1.useInjectable)(tree_model_service_1.SearchModelService);
    const commandService = (0, ide_core_browser_1.useInjectable)(ide_core_browser_1.CommandService);
    const wrapperRef = (0, react_1.useRef)(null);
    const totalRef = (0, react_1.useRef)(null);
    const [totalHeight, setTotalHeight] = (0, react_1.useState)(0);
    const { handleTreeBlur, handleTreeFocus } = searchModelService;
    (0, react_1.useEffect)(() => {
        setModel(searchModelService.treeModel);
        const disposable = searchModelService.onDidUpdateTreeModel((model) => {
            setModel(model);
        });
        return () => {
            disposable.dispose();
        };
    }, []);
    (0, react_1.useEffect)(() => {
        if (totalRef.current) {
            setTotalHeight(totalRef.current.clientHeight);
        }
    }, [totalRef.current]);
    const handleTreeReady = (0, react_1.useCallback)((handle) => {
        searchModelService.handleTreeHandler(handle);
    }, [searchModelService]);
    const renderTreeNode = (0, react_1.useCallback)((props) => (react_1.default.createElement(search_node_1.SearchNodeRendered, { item: props.item, itemType: props.itemType, decorations: searchModelService.decorations.getDecorations(props.item), defaultLeftPadding: 8, search: search, replace: replace, onClick: searchModelService.handleItemClick, onDoubleClick: searchModelService.handleItemDoubleClick, onContextMenu: searchModelService.handleContextMenu, leftPadding: 8, isUseRegexp: isUseRegexp, isMatchCase: isMatchCase, commandService: commandService })), [model, search, replace, isUseRegexp, isMatchCase]);
    const renderSearchTree = (0, react_1.useCallback)(() => {
        if (model) {
            return (react_1.default.createElement(ide_components_1.RecycleTree, { height: viewState.height - offsetTop - totalHeight, itemHeight: search_node_1.SEARCH_TREE_NODE_HEIGHT, onReady: handleTreeReady, model: model }, renderTreeNode));
        }
    }, [model, totalHeight, offsetTop, search, replace, isUseRegexp, isMatchCase, viewState]);
    return (react_1.default.createElement("div", { className: search_module_less_1.default.tree, tabIndex: -1, onBlur: handleTreeBlur, onFocus: handleTreeFocus, ref: wrapperRef },
        react_1.default.createElement("div", { ref: totalRef },
            react_1.default.createElement(ResultTotalContent, { total: total, state: state, model: model })),
        renderSearchTree()));
};
exports.SearchTree = SearchTree;
//# sourceMappingURL=search-tree.view.js.map