"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SearchModelService = exports.SearchTreeModel = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_components_1 = require("@opensumi/ide-components");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const index_1 = require("@opensumi/ide-core-browser/lib/menu/next/index");
const ide_editor_1 = require("@opensumi/ide-editor");
const monaco = tslib_1.__importStar(require("@opensumi/ide-monaco"));
const content_search_1 = require("../../common/content-search");
const search_preferences_1 = require("../search-preferences");
const search_tree_service_1 = require("./search-tree.service");
const tree_node_defined_1 = require("./tree-node.defined");
const tree_node_module_less_1 = tslib_1.__importDefault(require("./tree-node.module.less"));
let SearchTreeModel = class SearchTreeModel extends ide_components_1.TreeModel {
    constructor(root) {
        super();
        this.init(root);
    }
};
SearchTreeModel = tslib_1.__decorate([
    (0, di_1.Injectable)({ multiple: true }),
    tslib_1.__param(0, (0, di_1.Optional)()),
    tslib_1.__metadata("design:paramtypes", [tree_node_defined_1.SearchRoot])
], SearchTreeModel);
exports.SearchTreeModel = SearchTreeModel;
let SearchModelService = class SearchModelService extends ide_core_browser_1.Disposable {
    constructor() {
        super();
        // All decoration
        this.selectedDecoration = new ide_components_1.Decoration(tree_node_module_less_1.default.mod_selected); // selected
        this.focusedDecoration = new ide_components_1.Decoration(tree_node_module_less_1.default.mod_focused); // focused
        this.contextMenuDecoration = new ide_components_1.Decoration(tree_node_module_less_1.default.mod_actived); // contextMenu actived
        this._selectedNodes = [];
        this.onDidUpdateTreeModelEmitter = new ide_core_browser_1.Emitter();
        this.disposableCollection = new ide_core_browser_1.DisposableCollection();
        this.treeIsDirty = false;
        this.applyFocusedDecoration = (target, dispatch = true) => {
            var _a;
            if (this.contextMenuNode) {
                this.focusedDecoration.removeTarget(this.contextMenuNode);
                this.selectedDecoration.removeTarget(this.contextMenuNode);
                this.contextMenuDecoration.removeTarget(this.contextMenuNode);
                this._contextMenuNode = null;
            }
            if (target) {
                for (const target of this._selectedNodes) {
                    this.selectedDecoration.removeTarget(target);
                }
                if (this.focusedNode) {
                    this.focusedDecoration.removeTarget(this.focusedNode);
                }
                this.selectedDecoration.addTarget(target);
                this.focusedDecoration.addTarget(target);
                this._focusedNode = target;
                this._selectedNodes = [target];
                dispatch && ((_a = this.treeModel) === null || _a === void 0 ? void 0 : _a.dispatchChange());
            }
        };
        this.applyContextMenuDecoration = (target) => {
            if (this.contextMenuNode) {
                this.contextMenuDecoration.removeTarget(this.contextMenuNode);
            }
            if (this.focusedNode) {
                this.focusedDecoration.removeTarget(this.focusedNode);
                this._focusedNode = null;
            }
            this.contextMenuDecoration.addTarget(target);
            this._contextMenuNode = target;
            this.treeModel.dispatchChange();
        };
        this.removeFocusedDecoration = () => {
            var _a;
            if (this.focusedNode) {
                this.focusedDecoration.removeTarget(this.focusedNode);
                (_a = this.treeModel) === null || _a === void 0 ? void 0 : _a.dispatchChange();
            }
            this._focusedNode = null;
        };
        this.handleTreeBlur = () => {
            this.searchTreeService.contextKey.searchViewFocusedKey.set(false);
            this.removeFocusedDecoration();
        };
        this.handleTreeFocus = () => {
            this.searchTreeService.contextKey.searchViewFocusedKey.set(true);
        };
        this.handleContextMenu = (ev, node) => {
            if (!node) {
                this.removeFocusedDecoration();
                return;
            }
            this.applyContextMenuDecoration(node);
            const menus = this.contextMenuService.createMenu({
                id: index_1.MenuId.SearchContext,
                contextKeyService: this.searchTreeService.contextKey.service,
            });
            const menuNodes = menus.getMergedMenuNodes();
            menus.dispose();
            const { x, y } = ev.nativeEvent;
            this.ctxMenuRenderer.show({
                anchor: { x, y },
                menuNodes,
                args: [node],
            });
        };
        this.handleItemClick = async (ev, node, preview = true) => {
            this.applyFocusedDecoration(node);
            if (tree_node_defined_1.SearchFileNode.is(node)) {
                this.toggleDirectory(node);
            }
            else if (node.contentResult) {
                const result = node.contentResult;
                const isReplaceView = this.searchPreferences["search.useReplacePreview" /* SearchSettingId.UseReplacePreview */];
                if (isReplaceView && this.searchTreeService.replaceValue) {
                    // Open diff editor
                    const originalURI = new ide_core_browser_1.URI(result.fileUri);
                    const replaceURI = this.toReplaceResource(originalURI);
                    await this.replaceDocumentModelContentProvider.updateContent(replaceURI);
                    const openResourceResult = await this.workbenchEditorService.open(ide_core_browser_1.URI.from({
                        scheme: 'diff',
                        query: ide_core_browser_1.URI.stringifyQuery({
                            name: (0, ide_core_browser_1.formatLocalize)('search.fileReplaceChanges', originalURI.displayName, replaceURI.displayName),
                            original: originalURI,
                            modified: replaceURI,
                        }),
                    }), {
                        preview,
                    });
                    if (openResourceResult) {
                        const group = openResourceResult.group;
                        const editor = group.currentEditor;
                        if (editor) {
                            const monaco = editor.monacoEditor;
                            monaco.revealLineInCenter(result.line);
                        }
                    }
                    this.replaceDocumentModelContentProvider.delete(replaceURI);
                }
                else {
                    const uri = new ide_core_browser_1.URI(result.fileUri);
                    const openResourceResult = await this.workbenchEditorService.open(new ide_core_browser_1.URI(result.fileUri), {
                        preview,
                        focus: !preview,
                        range: {
                            startLineNumber: result.line,
                            startColumn: result.matchStart,
                            endLineNumber: result.line,
                            endColumn: result.matchStart + result.matchLength,
                        },
                    });
                    if (openResourceResult && !openResourceResult.resource.deleted) {
                        this.rangeHighlightDecorations.highlightRange(uri, new monaco.Range(result.line, result.matchStart, result.line, result.matchStart + result.matchLength));
                    }
                }
            }
        };
        this.handleItemDoubleClick = (ev, node) => {
            if (!tree_node_defined_1.SearchFileNode.is(node)) {
                this.handleItemClick(ev, node, false);
            }
        };
        this.toggleDirectory = (item) => {
            if (item.expanded) {
                this.searchTreeHandle.collapseNode(item);
            }
            else {
                this.searchTreeHandle.expandNode(item);
            }
        };
        this._whenReady = this.initTreeModel();
        this.addDispose(this.rangeHighlightDecorations);
    }
    get onDidUpdateTreeModel() {
        return this.onDidUpdateTreeModelEmitter.event;
    }
    get whenReady() {
        return this._whenReady;
    }
    get searchTreeHandle() {
        return this._searchTreeHandle;
    }
    get decorations() {
        return this._decorations;
    }
    get treeModel() {
        return this._treeModel;
    }
    get focusedNode() {
        return this._focusedNode;
    }
    get selectedNodes() {
        return this._selectedNodes;
    }
    get contextMenuNode() {
        return this._contextMenuNode;
    }
    async initTreeModel() {
        const childs = await this.searchTreeService.resolveChildren();
        if (!childs) {
            return;
        }
        const root = childs[0];
        if (!root) {
            return;
        }
        this._treeModel = this.injector.get(SearchTreeModel, [root]);
        await this._treeModel.ensureReady;
        this.initDecorations(root);
        this.disposables.push(this.searchService.onDidChange(() => {
            if (this.searchService.searchResults.size > 0) {
                this.searchTreeService.contextKey.hasSearchResults.set(true);
            }
            else {
                this.searchTreeService.contextKey.hasSearchResults.set(false);
            }
            this.refresh();
        }));
        this.onDidUpdateTreeModelEmitter.fire(this._treeModel);
    }
    initDecorations(root) {
        this._decorations = new ide_components_1.DecorationsManager(root);
        this._decorations.addDecoration(this.selectedDecoration);
        this._decorations.addDecoration(this.focusedDecoration);
        this._decorations.addDecoration(this.contextMenuDecoration);
        return this._decorations;
    }
    handleTreeHandler(handle) {
        this._searchTreeHandle = handle;
    }
    async refresh() {
        await this.whenReady;
        await this.searchTreeService.viewReady;
        (0, ide_core_browser_1.runWhenIdle)(() => {
            if (this.searchTreeService.contextKey && this.searchTreeService.contextKey.searchViewVisibleKey.get()) {
                this.treeModel.root.refresh();
            }
            else {
                this.treeIsDirty = true;
            }
        });
    }
    collapsedAll() {
        return this.treeModel.root.collapsedAll();
    }
    expandAll() {
        return this.treeModel.root.expandedAll();
    }
    toReplaceResource(fileResource) {
        const REPLACE_PREVIEW = 'replacePreview';
        return fileResource
            .withScheme(ide_core_browser_1.Schemes.internal)
            .withFragment(REPLACE_PREVIEW)
            .withQuery(JSON.stringify({ scheme: fileResource.scheme }));
    }
    activate() {
        if (this.searchTreeService.contextKey) {
            this.searchTreeService.contextKey.searchViewVisibleKey.set(true);
        }
        if (this.treeIsDirty) {
            this.refresh();
            this.treeIsDirty = false;
        }
    }
    deactivate() {
        if (this.searchTreeService.contextKey) {
            this.searchTreeService.contextKey.searchViewVisibleKey.set(false);
        }
    }
    dispose() {
        this.disposableCollection.dispose();
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(content_search_1.ISearchTreeService),
    tslib_1.__metadata("design:type", search_tree_service_1.SearchTreeService)
], SearchModelService.prototype, "searchTreeService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(content_search_1.IContentSearchClientService),
    tslib_1.__metadata("design:type", Object)
], SearchModelService.prototype, "searchService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_editor_1.WorkbenchEditorService),
    tslib_1.__metadata("design:type", ide_editor_1.WorkbenchEditorService)
], SearchModelService.prototype, "workbenchEditorService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(search_tree_service_1.ReplaceDocumentModelContentProvider),
    tslib_1.__metadata("design:type", search_tree_service_1.ReplaceDocumentModelContentProvider)
], SearchModelService.prototype, "replaceDocumentModelContentProvider", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(search_tree_service_1.RangeHighlightDecorations),
    tslib_1.__metadata("design:type", search_tree_service_1.RangeHighlightDecorations)
], SearchModelService.prototype, "rangeHighlightDecorations", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(index_1.ICtxMenuRenderer),
    tslib_1.__metadata("design:type", index_1.ICtxMenuRenderer)
], SearchModelService.prototype, "ctxMenuRenderer", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(index_1.AbstractContextMenuService),
    tslib_1.__metadata("design:type", index_1.AbstractContextMenuService)
], SearchModelService.prototype, "contextMenuService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(di_1.INJECTOR_TOKEN),
    tslib_1.__metadata("design:type", di_1.Injector)
], SearchModelService.prototype, "injector", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(search_preferences_1.SearchPreferences),
    tslib_1.__metadata("design:type", Object)
], SearchModelService.prototype, "searchPreferences", void 0);
SearchModelService = tslib_1.__decorate([
    (0, di_1.Injectable)(),
    tslib_1.__metadata("design:paramtypes", [])
], SearchModelService);
exports.SearchModelService = SearchModelService;
//# sourceMappingURL=tree-model.service.js.map